Improve this doc View Source

Specify custom behavior on cut event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as attribute:

      <window, input, select, textarea, a
        ng-cut="">
      ...
      </window, input, select, textarea, a>

### Arguments

Param | Type | Details
--- | --- | ---
ngCut | expression | Expression to evaluate upon cut. (Event object is available as `$event`)

## Example

Edit in Plunker

    <input ng-cut="cut=true" ng-init="cut=false; value='cut me'" ng-model="value">
    cut: {{cut}}